Description Dictionary Super classes Methods References See Also Examples
Regression conditional random forest learner.
Calls partykit::cforest() from package partykit.
This Learner can be instantiated via the dictionary mlr_learners or with the associated sugar function lrn():
1 2 | mlr_learners$get("regr.cforest")
lrn("regr.cforest")
|
mlr3::Learner -> mlr3::LearnerRegr -> LearnerRegrCForest
new()Creates a new instance of this R6 class.
LearnerRegrCForest$new()
oob_error()The out-of-bag error, calculated using the OOB predictions from
partykit.
LearnerRegrCForest$oob_error()
numeric(1).
clone()The objects of this class are cloneable with this method.
LearnerRegrCForest$clone(deep = FALSE)
deepWhether to make a deep clone.
mlr3learners.partykitpartykit1 mlr3learners.partykitpartykit2
Dictionary of Learners: mlr3::mlr_learners
1 2 3 4 5 6 7 | if (requireNamespace("partykit")) {
learner = mlr3::lrn("regr.cforest")
print(learner)
# available parameters:
learner$param_set$ids()
}
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.